@@ -464,7 +464,11 @@ async def {edge_name}(self, resolver: {resolver_name} = None, refresh: bool = Fa
         return f"""
 @classmethod
 async def add(cls, *, input: {self.node_config.add_model}, resolver: {self.resolver_name} = None{upsert_str}) -> {self.node_name}:
-    return await cls._add(input=input, given_resolver=resolver, upsert={"upsert" if has_upsert else "None"})
+    return (await cls.add_many(inputs=[input], resolver=resolver, upsert=upsert))[0]
+
+@classmethod
+async def add_many(cls, *, inputs: List[{self.node_config.add_model}], resolver: {self.resolver_name} = None{upsert_str}) -> List[{self.node_name}]:
+    return await cls._add(inputs=inputs, given_resolver=resolver, upsert={"upsert" if has_upsert else "None"})
         """
 
     def build_update(self) -> str:
