@@ -366,23 +366,20 @@ class Node(BaseModel):
     async def _add(
         cls: T.Type[NodeModel],
         *,
-        input: GQL.add_model,
+        inputs: T.List[GQL.add_model],
         given_resolver: T.Optional[ResolverType] = None,
         upsert: bool = None,
-    ) -> NodeModel:
+    ) -> T.List[NodeModel]:
         resolver = given_resolver or cls.GQL.resolver()
         query_str = resolver.make_add_mutation_str(include_upsert=upsert is not None)
-        if not isinstance(input, cls.GQL.add_model):
-            input = cls.GQL.add_model.parse_obj(input)
-
-        input_d = jsonable_encoder(input)
-
-        variables = {"input": jsonable_encoder(input_d)}
+        variables = {"input": jsonable_encoder(inputs)}
         if upsert is not None:
             variables["upsert"] = upsert
         j = await gql(query_str=query_str, variables=variables, url=cls.GQL.url)
-        node_d = j["data"][f"{cls.GQL.add_function_name}"][cls.GQL.payload_node_name][0]
-        return resolver.parse_obj_nested(node_d)
+        node_d_lst = j["data"][f"{cls.GQL.add_function_name}"][
+            cls.GQL.payload_node_name
+        ]
+        return [resolver.parse_obj_nested(node_d) for node_d in node_d_lst]
 
     @staticmethod
     def make_gql_d_from_rel_d_input(rel_d_input: REL_D_INPUT) -> GQL_D:
